/*
 * @Author: ysh
 * @Date: 2024-06-13 17:07:59
 * @LastEditors: Please set LastEditors
 * @LastEditTime: 2024-07-04 10:38:39
 */
import request from '@/utils/request'

const apiEndpoints = [
  {
    procDefName: '承接合同评审',
    apiUrl: [
      '/oa/contract/:id',
      '/oa/contractWork/:id',
      '/oa/contractComment/:id',
      '/oa/contractMeeting/:id',
      '/oa/contractPayment/:id',
      '/oa/projectContract/:id',
    ]
  },
  {
    procDefName: '分包合同评审',
    apiUrl: [
      '/oa/subContract/:id',
      '/oa/contractWork/:id',
      '/oa/contractComment/:id',
      '/oa/contractMeeting/:id',
      '/oa/contractPayment/:id',
      '/oa/projectSubcontract/:id',
    ]
  },
  {
    procDefName: '用车审批',
    apiUrl: [
      '/oa/carApproval/:id',
    ]
  },
  {
    procDefName: '项目流转',
    apiUrl: [
      '/oa/project/:id',
      '/oa/projectWork/:id',
    ]
  },
  {
    procDefName: '项目结算',
    apiUrl: [
      '/oa/settle/:id',
      '/oa/settleSummary/:id',
      '/oa/settleWork/:id',
    ]
  },
  {
    procDefName: '借款审批',
    apiUrl: [
      '/oa/borrow/:id',
      '/oa/borrowDetail/:id',
    ]
  }
]

// 编写一个方法来处理删除请求，并同时发送所有API请求  
export async function deleteResources(procDefName, id) {  
  // 查找对应的API端点  
  const endpoint = apiEndpoints.find(endpoint => endpoint.procDefName === procDefName);  
  if (!endpoint) {  
    throw new Error(`No API endpoints found for process definition: ${procDefName}`);  
  }  
    
  // 构建所有请求的Promise数组  
  const deletePromises = endpoint.apiUrl.map(apiUrl => {  
    // 替换URL中的:id占位符  
    const url = apiUrl.replace(':id', id);  
    // 发送DELETE请求并返回Promise  
    return request.delete(url)  
  });  
    
  // 等待所有请求完成  
  try {  
    return await Promise.all(deletePromises);  
    console.log('删除完成！');  
  } catch (error) {  
    console.error('One or more deletion requests failed:', error);  
  }  
} 